#
# Copyright (c) 2016 Sam4Mobile, 2017 Make.org
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

# We need an initiator node before attempting any config
run_state = node.run_state[cookbook_name]
return if run_state.nil? || run_state['initiator'].nil?

# Generate options hash from attribute
options = node[cookbook_name]['options'].to_hash

# Create cockroachdb store if custom store defined in options hash
if node[cookbook_name]['options']['store']
  store = node[cookbook_name]['options']['store']
  directory store do
    user node[cookbook_name]['user']
    group node[cookbook_name]['user']
    mode '0755'
    recursive true
  end
end

cockroachdb_dir = "#{node[cookbook_name]['prefix_root']}/cockroachdb"
# Deploy data bag in secure mode
if node[cookbook_name]['options']['insecure'].nil?
  # Create directory for ssl certs storage
  directory "#{cockroachdb_dir}/certs" do
    user node[cookbook_name]['user']
    mode '0750'
  end

  # Load certs from encrypted data bag
  data_bag = node[cookbook_name]['data_bag']

  %w[crt key].each do |ext|
    # Create only SSL ca
    file "#{cockroachdb_dir}/certs/ca.#{ext}" do
      content data_bag_item(data_bag['name'], data_bag['ca'])[ext]
      user node[cookbook_name]['user']
      mode mode '0600'
    end
  end

  # Set ssl option parameter
  options['certs-dir'] = "#{cockroachdb_dir}/certs"

  # Node certificates are generated for each node
  bash 'gen node certs' do
    cwd cockroachdb_dir
    code <<-EOF
      ./cockroach cert create-node\
      --certs-dir=#{options['certs-dir']}\
      --ca-key=#{options['certs-dir']}/ca.key\
      #{node[cookbook_name]['node_hostnames'].join(' ')}
      chown -R #{node[cookbook_name]['user']} certs/node.*
    EOF
    not_if { ::File.exist?('certs/node.crt') }
  end
end

# Set custom options parameters if node have to join cluster
unless node.run_state[cookbook_name]['iam_initiator']
  options['join'] = node.run_state[cookbook_name]['initiator']
end

# Store options to reuse them later
node.run_state[cookbook_name]['options'] = options
